# Parametric example

Simple example for generating a lot of files to test system behaviour.

This is not a good, clean example of how to write and structure a Byggfile.py since the generating of
the input files reduces clarity.

However, it is still useful for testing purposes.

See the beginning of Byggfile.py for documentation of the various parameters that can be set.
